@@ -22,7 +22,6 @@ OC.L10N.register(
     "Appointments" : "Cites",
     "Schedule appointment \"%s\"" : "Agenda la cita \"%s\"",
     "Schedule an appointment" : "Agenda una cita",
-    "%1$s - %2$s" : "%1$s - %2$s",
     "Prepare for %s" : "Preparar-se per a %s",
     "Follow up for %s" : "Seguiment de %s",
     "Your appointment \"%s\" with %s needs confirmation" : "La vostra cita \"%s\" amb %s necessita confirmació",
@@ -41,6 +40,7 @@ OC.L10N.register(
     "Comment:" : "Comentari:",
     "You have a new appointment booking \"%s\" from %s" : "Tens una nova reserva de cita \"%s\" de %s",
     "Dear %s, %s (%s) booked an appointment with you." : "Benvolgut %s, %s (%s) ha reservat una cita amb tu.",
+    "Location:" : "Ubicació:",
     "A Calendar app for Nextcloud" : "Una aplicació de calendari per al Nextcloud",
     "Previous day" : "Dia anterior",
     "Previous week" : "Setmana anterior",
@@ -62,6 +62,7 @@ OC.L10N.register(
     "Appointment link could not be copied to clipboard" : "No s'ha pogut copiar l'enllaç de la cita al porta-retalls",
     "Preview" : "Previsualitza",
     "Copy link" : "Copia l'enllaç",
+    "Duplicate" : "Duplica",
     "Edit" : "Edició",
     "Delete" : "Suprimeix",
     "Appointment schedules" : "Horaris de cites",
@@ -114,7 +115,6 @@ OC.L10N.register(
     "Could not update calendar order." : "No s'ha pogut actualitzar l'ordre del calendari.",
     "Shared calendars" : "Calendaris compartits",
     "Deck" : "Targetes",
-    "Hidden" : "Ocult",
     "Internal link" : "Enllaç intern",
     "A private link that can be used with external clients" : "Un enllaç privat que pot utilitzar-se amb clients externs",
     "Copy internal link" : "Copia l'enllaç intern",
@@ -137,16 +137,15 @@ OC.L10N.register(
     "{teamDisplayName} (Team)" : "{teamDisplayName} (Equip)",
     "An error occurred while unsharing the calendar." : "S'ha produït un error en deixar de compartir el calendari.",
     "An error occurred, unable to change the permission of the share." : "Ha succeït un error i no s'ha pogut canviar els permisos de compartició.",
-    "can edit" : "pot editar-lo",
     "Unshare with {displayName}" : "S'ha deixat de compartir amb {displayName}",
     "Share with users or groups" : "Comparteix amb usuaris o grups",
     "No users or groups" : "No hi ha usuaris ni grups",
     "Failed to save calendar name and color" : "No s'ha pogut desar el nom i el color del calendari",
-    "Calendar name …" : "Nom del calendari …",
     "Never show me as busy (set this calendar to transparent)" : "No em mostris mai com a ocupat (configura aquest calendari com a transparent)",
     "Share calendar" : "Comparteix el calendari",
     "Unshare from me" : "Deixa de compartir",
     "Save" : "Desa",
+    "View" : "Visualització",
     "Import calendars" : "Importació calendaris",
     "Please select a calendar to import into …" : "Escolliu un calendari per ser importat …",
     "Filename" : "Nom del fitxer",
@@ -158,14 +157,15 @@ OC.L10N.register(
     "Invalid location selected" : "La ubicació seleccionada no és vàlida",
     "Attachments folder successfully saved." : "La carpeta de fitxers adjunts s'ha desat correctament.",
     "Error on saving attachments folder." : "Error en desar la carpeta de fitxers adjunts.",
-    "Default attachments location" : "Ubicació per defecte dels fitxers adjunts",
+    "Attachments folder" : "Carpeta fitxers adjunts",
     "{filename} could not be parsed" : "No s'ha pogut entendre el contingut del fitxer {filename}",
     "No valid files found, aborting import" : "No s'han trobat fitxers que siguin vàlids i s'ha avortat la importació",
     "_Successfully imported %n event_::_Successfully imported %n events_" : ["S'ha importat correctament %n esdeveniment","S'ha importat correctament %n esdeveniments"],
     "Import partially failed. Imported {accepted} out of {total}." : "La importació ha fallat parcialment. S'han importat {accepted} d'un total de {total}.",
     "Automatic" : "Automàtic",
-    "Automatic ({detected})" : "Automàtic ({detected})",
+    "Automatic ({timezone})" : "Automàtic ({timezone})",
     "New setting was not saved successfully." : "No s'ha desat correctament els nous paràmetres.",
+    "Timezone" : "Fus horari",
     "Navigation" : "Navegació",
     "Previous period" : "Període anterior",
     "Next period" : "Període següent",
@@ -183,27 +183,16 @@ OC.L10N.register(
     "Save edited event" : "Desa l'esdeveniment editat",
     "Delete edited event" : "Suprimeix l'esdeveniment editat",
     "Duplicate event" : "Esdeveniment duplicat",
-    "Shortcut overview" : "Descripció general de la drecera",
     "or" : "o",
     "Calendar settings" : "Paràmetres de Calendari",
     "At event start" : "A l'inici de l'esdeveniment",
     "No reminder" : "Sense recordatoris",
     "Failed to save default calendar" : "No s'ha pogut desar el calendari predeterminat",
-    "CalDAV link copied to clipboard." : "S'ha copiat al porta-retalls l'enllaç CalDAV.",
-    "CalDAV link could not be copied to clipboard." : "No s'ha pogut copiar al porta-retalls l'enllaç CalDAV.",
-    "Enable birthday calendar" : "Habilitar el calendari d'aniversaris",
-    "Show tasks in calendar" : "Mostra les tasques en el calendari",
-    "Enable simplified editor" : "Habilitar l'editor simplificat",
-    "Limit the number of events displayed in the monthly view" : "Limita el nombre d'esdeveniments que es mostren a la vista mensual",
-    "Show weekends" : "Mostra els caps de setmana",
-    "Show week numbers" : "Mostra el número de la setmana",
-    "Time increments" : "Increments de temps",
-    "Default calendar for incoming invitations" : "Calendari predeterminat per a les invitacions entrants",
+    "General" : "General",
+    "Appearance" : "Aparença",
+    "Editing" : "Edició",
     "Default reminder" : "Recordatori per defecte",
-    "Copy primary CalDAV address" : "Copia l'adreça CalDAV primària",
-    "Copy iOS/macOS CalDAV address" : "Copia l'adreça CalDAV iOS/macOS",
-    "Personal availability settings" : "Paràmetres de disponibilitat personal",
-    "Show keyboard shortcuts" : "Mostra les dreceres del teclat",
+    "Files" : "Fitxers",
     "Appointment schedule successfully created" : "S'ha creat correctament la planificació de cites",
     "Appointment schedule successfully updated" : "La planificació de cites s'ha actualitzat correctament",
     "_{duration} minute_::_{duration} minutes_" : ["{duration} minut","{duration} minuts"],
@@ -220,6 +209,7 @@ OC.L10N.register(
     "Create appointment schedule" : "Crea d'una planificació de cites",
     "Edit appointment schedule" : "Edició la planificació de cites",
     "Update" : "Actualitza",
+    "(copy)" : "(còpia)",
     "Appointment name" : "Nom de la cita",
     "Location" : "Ubicació",
     "Create a Talk room" : "Crea una sala de Converses",
@@ -263,9 +253,9 @@ OC.L10N.register(
     "Successfully added Talk conversation link to location." : "S'ha afegit correctament l'enllaç de Converses a la ubicació.",
     "Successfully added Talk conversation link to description." : "S'ha afegit correctament l'enllaç de Converses a la descripció.",
     "Failed to apply Talk room." : "No s'ha pogut aplicar la sala de Converses.",
+    "Talk conversation for event" : "Converses per a l'esdeveniment",
     "Error creating Talk conversation" : "S'ha produït un error en crear la Converses",
     "Select a Talk Room" : "Seleccioneu una sala de Converses",
-    "Add Talk conversation" : "Afegeix una Converses",
     "Fetching Talk rooms…" : "S'estan obtenint sales de Converses…",
     "No Talk room available" : "No hi ha sala de Converses disponible",
     "Select conversation" : "Seleccioneu una conversa",
@@ -344,13 +334,9 @@ OC.L10N.register(
     "Accept" : "Accepta",
     "Decline" : "Rebutja",
     "Tentative" : "Provisional",
+    "Copied to clipboard" : "Copiat al porta-retalls",
     "No attendees yet" : "Encara no hi ha cap participant",
-    "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount} convidats, {confirmedCount} confirmats",
-    "Successfully appended link to talk room to location." : "S'ha afegit correctament l'enllaç a la sala de conversa a la ubicació.",
-    "Successfully appended link to talk room to description." : "S'ha afegit l'enllaç d'una nova sala de Talk a la descripció de l'esdeveniment.",
-    "Error creating Talk room" : "Ha succeït un error tractant de crear la sala a Talk",
     "Attendees" : "Assistents",
-    "_%n more guest_::_%n more guests_" : ["%n convidat més","%n convidats més"],
     "Remove group" : "Suprimir el grup",
     "Remove attendee" : "Suprimeix el participant",
     "Request reply" : "Sol·licitar resposta",
@@ -416,6 +402,12 @@ OC.L10N.register(
     "Update this occurrence" : "Actualitza aquesta ocurrència",
     "Public calendar does not exist" : "No existeix un calendari públic",
     "Maybe the share was deleted or has expired?" : "Potser la compartició va ser esborrada o va expirar?",
+    "Remove participant" : "Suprimir el participant",
+    "Yes" : "Sí",
+    "No" : "No",
+    "Maybe" : "Potser",
+    "None" : "Només una vegada",
+    "Create" : "Crea",
     "from {formattedDate}" : "de {formattedDate}",
     "to {formattedDate}" : "a {formattedDate}",
     "on {formattedDate}" : "el {formattedDate}",
@@ -461,13 +453,14 @@ OC.L10N.register(
     "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "La detecció automàtica de la zona horària va determinar que la vostra zona horària fos UTC.\nÉs probable que això sigui el resultat de les mesures de seguretat del vostre navegador web.\nSi us plau, configureu la vostra zona horària manualment a la configuració del calendari.",
     "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "No s'ha trobat la vostra zona horària configurada ({timezoneId}). Tornant a l'UTC.\nCanvieu la vostra zona horària a la configuració i informeu d'aquest problema.",
     "Availability of {displayName}" : "Disponibilitat de {displayName}",
+    "Discard changes" : "Descarta els canvis",
     "Edit event" : "Edita l'esdeveniment",
     "Event does not exist" : "L'esdeveniment no existeix",
-    "Duplicate" : "Duplica",
     "Delete this occurrence" : "Suprimeix aquesta ocurrència",
     "Delete this and all future" : "Suprimeix aquesta i les ocurrències futures",
     "All day" : "Tot el dia",
     "Modifications wont get propagated to the organizer and other attendees" : "Les modificacions no es propagaran a l'organitzador i als altres assistents",
+    "Add Talk conversation" : "Afegeix a Converses",
     "Managing shared access" : "Gestió de l'accés compartit",
     "Deny access" : "Denega l'accés",
     "Invite" : "Convida",
@@ -476,6 +469,12 @@ OC.L10N.register(
     "Untitled event" : "Esdeveniment sense títol",
     "Close" : "Tanca",
     "Modifications will not get propagated to the organizer and other attendees" : "Les modificacions no es propagaran a l'organitzador i als altres assistents",
+    "This event was cancelled" : "Aquest esdeveniment s'ha cancel·lat",
+    "Selected" : "Seleccionat",
+    "Title" : "Títol",
+    "30 min" : "30 min",
+    "Participants" : "Participants",
+    "Submit" : "Envia",
     "Subscribe to {name}" : "Subscriure a {name}",
     "Export {name}" : "Exporta {name}",
     "Show availability" : "Mostra disponibilitat",
@@ -551,7 +550,6 @@ OC.L10N.register(
     "When shared show full event" : "Quan es comparteix, mostra l'esdeveniment complet",
     "When shared show only busy" : "Quan es comparteix, mostra només si està ocupat",
     "When shared hide this event" : "Quan es comparteix, amaga aquest esdeveniment",
-    "The visibility of this event in shared calendars." : "La visibilitat de l'event en calendaris compartits.",
     "Add a location" : "Afegeix una ubicació",
     "Add a description\n\n- What is this meeting about\n- Agenda items\n- Anything participants need to prepare" : "Afegeix una descripció\n\n- De què tracta aquesta reunió\n- Elements de l'ordre del dia\n- Qualsevol cosa que els participants hagin de preparar",
     "Status" : "Estat",
@@ -570,12 +568,38 @@ OC.L10N.register(
     "Error while sharing file with user" : "S'ha produït un error en compartir el fitxer amb l'usuari",
     "Attachment {fileName} already exists!" : "El fitxer adjunt {fileName} ja existeix!",
     "An error occurred during getting file information" : "S'ha produït un error en obtenir la informació del fitxer",
-    "Talk conversation for event" : "Converses per a l'esdeveniment",
     "An error occurred, unable to delete the calendar." : "S'ha produït un error. No s'ha suprimit el calendari.",
     "Imported {filename}" : "{filename} importat",
     "This is an event reminder." : "Això és un recordatori de l'esdeveniment.",
     "Error while parsing a PROPFIND error" : "S'ha produït un error en analitzar un error PROPFIND",
     "Appointment not found" : "No s'ha trobat la cita",
-    "User not found" : "No s'ha trobat l'usuari"
+    "User not found" : "No s'ha trobat l'usuari",
+    "%1$s - %2$s" : "%1$s - %2$s",
+    "Hidden" : "Ocult",
+    "can edit" : "pot editar-lo",
+    "Calendar name …" : "Nom del calendari …",
+    "Default attachments location" : "Ubicació per defecte dels fitxers adjunts",
+    "Automatic ({detected})" : "Automàtic ({detected})",
+    "Shortcut overview" : "Descripció general de la drecera",
+    "CalDAV link copied to clipboard." : "S'ha copiat al porta-retalls l'enllaç CalDAV.",
+    "CalDAV link could not be copied to clipboard." : "No s'ha pogut copiar al porta-retalls l'enllaç CalDAV.",
+    "Enable birthday calendar" : "Habilitar el calendari d'aniversaris",
+    "Show tasks in calendar" : "Mostra les tasques en el calendari",
+    "Enable simplified editor" : "Habilitar l'editor simplificat",
+    "Limit the number of events displayed in the monthly view" : "Limita el nombre d'esdeveniments que es mostren a la vista mensual",
+    "Show weekends" : "Mostra els caps de setmana",
+    "Show week numbers" : "Mostra el número de la setmana",
+    "Time increments" : "Increments de temps",
+    "Default calendar for incoming invitations" : "Calendari predeterminat per a les invitacions entrants",
+    "Copy primary CalDAV address" : "Copia l'adreça CalDAV primària",
+    "Copy iOS/macOS CalDAV address" : "Copia l'adreça CalDAV iOS/macOS",
+    "Personal availability settings" : "Paràmetres de disponibilitat personal",
+    "Show keyboard shortcuts" : "Mostra les dreceres del teclat",
+    "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount} convidats, {confirmedCount} confirmats",
+    "Successfully appended link to talk room to location." : "S'ha afegit correctament l'enllaç a la sala de conversa a la ubicació.",
+    "Successfully appended link to talk room to description." : "S'ha afegit l'enllaç d'una nova sala de Talk a la descripció de l'esdeveniment.",
+    "Error creating Talk room" : "Ha succeït un error tractant de crear la sala a Talk",
+    "_%n more guest_::_%n more guests_" : ["%n convidat més","%n convidats més"],
+    "The visibility of this event in shared calendars." : "La visibilitat de l'event en calendaris compartits."
 },
 "nplurals=2; plural=(n != 1);");
