@@ -37,7 +37,7 @@ OC.L10N.register(
     "Actions" : "Acciones",
     "or" : "o",
     "General" : "General",
-    "Keyboard shortcuts" : "Atajos del teclado",
+    "Files" : "Archivo",
     "Update" : "Actualizar",
     "Location" : "Ubicación",
     "Description" : "Descripción",
@@ -63,6 +63,7 @@ OC.L10N.register(
     "Accept" : "Aceptar",
     "Decline" : "Declinar",
     "Tentative" : "Tentativo",
+    "Copied to clipboard" : "Copiado al portapapeles",
     "Attendees" : "Asistentes",
     "Repeat" : "Repetir",
     "never" : "nunca",
