@@ -389,6 +389,7 @@ OC.L10N.register(
     "Personal" : "شخصی",
     "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings.",
     "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue.",
+    "Discard changes" : "Discard changes",
     "Edit event" : "ویرایش رویداد",
     "Event does not exist" : "رویداد وجود ندارد",
     "Delete this occurrence" : "این رخداد را حذف کنید",
@@ -401,6 +402,7 @@ OC.L10N.register(
     "_Attachment requires shared access_::_Attachments requiring shared access_" : ["Attachment requires shared access","Attachments requiring shared access"],
     "Untitled event" : "رویداد بدون عنوان",
     "Close" : "بستن",
+    "This event was cancelled" : "This event was cancelled",
     "Title" : "Title",
     "30 min" : "30 min",
     "Participants" : "شركت كنندگان",
