@@ -49,6 +49,7 @@ OC.L10N.register(
     "Dates:" : "Päivät:",
     "Respond" : "Vastaa",
     "[Proposed] %1$s" : "[Ehdotettu] %1$s",
+    "Calendar App" : "Kalenterisovellus",
     "A Calendar app for Nextcloud" : "Kalenterisovellus Nextcloudille",
     "Previous day" : "Edellinen päivä",
     "Previous week" : "Edellinen viikko",
@@ -365,6 +366,8 @@ OC.L10N.register(
     "Decline" : "Kieltäydy",
     "Tentative" : "Alustava",
     "Copied to clipboard" : "Kopioitu leikepöydälle",
+    "Failed to copy" : "Kopiointi epäonnistui",
+    "Copy name and email address" : "Kopioi nimi ja sähköpostiosoite",
     "No attendees yet" : "Ei vielä osallistujia",
     "Attendees" : "Osallistujat",
     "Remove group" : "Poista ryhmä",
@@ -479,7 +482,7 @@ OC.L10N.register(
     "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Asettamaasi aikavyöhykettä ({timezoneId}) ei löytynyt. Vaihdetaan takaisin UTC:hen.\nOle hyvä ja vaihda aikavyöhykkeesi asetuksista ja ilmoita tästä ongelmasta.",
     "Show unscheduled tasks" : "Näytä ajastamattomat tehtävät",
     "Unscheduled tasks" : "Ajastamattomat tehtävät",
-    "Discard event" : "Hylkää tapahtuma",
+    "Discard changes" : "Hylkää muutokset",
     "Edit event" : "Muokkaa tapahtumaa",
     "Event does not exist" : "Tapahtumaa ei ole olemassa",
     "Delete this occurrence" : "Poista tämä esiintymä",
@@ -494,6 +497,7 @@ OC.L10N.register(
     "_User requires access to your file_::_Users require access to your file_" : ["Käyttäjä tarvitsee pääsyn tiedostoosi","Käyttäjät tarvitsevat pääsyn tiedostoosi"],
     "Untitled event" : "Nimetön tapahtuma",
     "Close" : "Sulje",
+    "This event was cancelled" : "Tämä tapahtuma peruttiin",
     "Meeting proposals overview" : "Kokousehdotusten yhteenveto",
     "Edit meeting proposal" : "Muokkaa kokousehdotusta",
     "Create meeting proposal" : "Luo kokousehdotus",
