@@ -130,6 +130,7 @@ OC.L10N.register(
     "Default reminder" : "Zadani podsjetnik",
     "Files" : "Datoteke",
     "Update" : "Ažuriraj",
+    "(copy)" : "(kopiraj)",
     "Location" : "Lokacija",
     "Description" : "Opis",
     "Visibility" : "Vidljivost",
@@ -144,7 +145,9 @@ OC.L10N.register(
     "Friday" : "Petak",
     "Saturday" : "Subota",
     "Sunday" : "Nedjelja",
+    "Weekdays" : "Dani u tjednu",
     "Your email address" : "Vaša adresa e-pošte",
+    "Back" : "Natrag",
     "Select conversation" : "Odaberi razgovor",
     "on" : "na",
     "at" : "u",
@@ -174,6 +177,7 @@ OC.L10N.register(
     "Availability of attendees, resources and rooms" : "Raspoloživost sudionika, resursa i soba",
     "Out of office" : "Izvan ureda",
     "Attendees:" : "Polaznici:",
+    "Done" : "Gotovo",
     "Room name" : "Naziv sobe",
     "Free" : "Dostupno",
     "Busy (tentative)" : "Zauzeto (uvjetno)",
@@ -264,6 +268,7 @@ OC.L10N.register(
     "Personal" : "Osobno",
     "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "Značajka automatskog otkrivanja vremenske zone utvrdila je vašu vremensku zonu kao UTC.\nVjerojatno zbog sigurnosnih mjera vašeg internetskog preglednika.\nRučno postavite vremensku zonu u postavkama kalendara.",
     "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Nije pronađena vaša konfigurirana vremenska zona ({timezoneId}). Postavka vremenske zone vraćena je na UTC.\nPromijenite vremensku zonu u postavkama i prijavite ovu poteškoću.",
+    "Discard changes" : "Odbaci promjene",
     "Edit event" : "Uredi događaj",
     "Event does not exist" : "Događaj ne postoji",
     "Delete this occurrence" : "Izbriši ovo ponavljanje",
