@@ -445,6 +445,7 @@ OC.L10N.register(
     "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "Sjálfvirka tímabeltisgreiningin ákvarðaði tímabeltið þitt sem UTC.\nLíklega er það vegna öryggisstillinga í vafranum þínum.\nStilltu tímabeltið þitt í stillingum dagatalsins.",
     "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Stillta tímabeltið þitt ({timezoneId}) fannst ekki. Nota UTC til vara.\nStilltu tímabeltið þitt í stillingum dagatalsins og tilkynntu þetta vandamál.",
     "Availability of {displayName}" : "Lausir tímar hjá {displayName}",
+    "Discard changes" : "Henda breytingum",
     "Edit event" : "Breyta atburði",
     "Event does not exist" : "Atburður er ekki til",
     "Delete this occurrence" : "Eyða þessu tilviki",
@@ -458,6 +459,7 @@ OC.L10N.register(
     "_Attachment requires shared access_::_Attachments requiring shared access_" : ["Viðhengi krefst sameiginlegs aðgangs","Viðhengi krefjast sameiginlegs aðgangs"],
     "Untitled event" : "Ónefndur atburður",
     "Close" : "Loka",
+    "This event was cancelled" : "Hætt hefur verið við þennan atburð",
     "Participants" : "Þátttakendur",
     "Submit" : "Senda inn",
     "Subscribe to {name}" : "Panta áskrift að {name}",
