@@ -22,7 +22,6 @@ OC.L10N.register(
     "Appointments" : "予定",
     "Schedule appointment \"%s\"" : "予定を入れる \"%s\"",
     "Schedule an appointment" : "予定を入れる",
-    "%1$s - %2$s" : "%1$s - %2$s",
     "Prepare for %s" : " %s の準備",
     "Follow up for %s" : "%s に対するフォローアップ",
     "Your appointment \"%s\" with %s needs confirmation" : "あなたの \"%s\" との予定 %s には確認が必要",
@@ -63,6 +62,7 @@ OC.L10N.register(
     "Appointment link could not be copied to clipboard" : "予定リンクをクリップボードにコピーできませんでした",
     "Preview" : "プレビュー",
     "Copy link" : "リンクをコピー",
+    "Duplicate" : "複製",
     "Edit" : "編集",
     "Delete" : "削除",
     "Appointment schedules" : "予約スケジュール",
@@ -206,6 +206,7 @@ OC.L10N.register(
     "Public – shown on the profile page" : "公開 - プロフィールページに表示されます。",
     "Private – only accessible via secret link" : "非公開 - 秘密のリンクからしかアクセスできません。",
     "Update" : "更新",
+    "(copy)" : "(copy)",
     "Appointment name" : "予定名",
     "Location" : "場所",
     "Create a Talk room" : "通話ルームを作成",
@@ -244,7 +245,6 @@ OC.L10N.register(
     "Could not book the appointment. Please try again later or contact the organizer." : "予約できませんでした。後でもう一度試してみるか、主催者に連絡してください。",
     "Back" : "戻る",
     "Successfully added Talk conversation link to location." : "トークへのリンクをロケーションに追加しました。",
-    "Add Talk conversation" : "会話を追加",
     "Select conversation" : "会話を選択",
     "on" : "曜日",
     "at" : "で",
@@ -316,6 +316,7 @@ OC.L10N.register(
     "Accept" : "承諾",
     "Decline" : "拒否",
     "Tentative" : "暫定的",
+    "Copied to clipboard" : "クリップボードにコピーされました",
     "No attendees yet" : "出席者はまだいません",
     "Attendees" : "参加者",
     "Remove group" : "グループを削除",
@@ -429,13 +430,13 @@ OC.L10N.register(
     "Personal" : "個人",
     "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "自動的なタイムゾーンの検出により、あなたのタイムゾーンはUTCと判断されました。\nこれはおそらく、あなたのウェブブラウザのセキュリティ対策の結果です。\nカレンダーの設定でタイムゾーンを手動で設定してください。",
     "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "設定されたタイムゾーン ({timezoneId}) が見つかりませんでした。UTCにフォールバックします。\n設定でタイムゾーンを変更して、この問題を報告してください。",
-    "Discard event" : "イベントを破棄",
+    "Discard changes" : "変更を破棄する",
     "Edit event" : "イベントを編集",
     "Event does not exist" : "イベントは存在しません",
-    "Duplicate" : "複製",
     "Delete this occurrence" : "この出来事を削除",
     "Delete this and all future" : "これ以降を削除する",
     "All day" : "終日",
+    "Add Talk conversation" : "会話を追加",
     "Managing shared access" : "共有アクセスの管理",
     "Deny access" : "アクセスを拒否する",
     "Invite" : "招待状",
@@ -444,6 +445,7 @@ OC.L10N.register(
     "_Attachment requires shared access_::_Attachments requiring shared access_" : ["添付ファイルには共有アクセスが必要です"],
     "Untitled event" : "無題のイベント",
     "Close" : "閉じる",
+    "This event was cancelled" : "このイベントはキャンセルされました",
     "Selected" : "選択済み",
     "Title" : "タイトル",
     "30 min" : "30分",
@@ -540,6 +542,7 @@ OC.L10N.register(
     "This is an event reminder." : "これはイベントのリマインダーです。",
     "Appointment not found" : "予定が見つかりません",
     "User not found" : "ユーザーが見つかりません",
+    "%1$s - %2$s" : "%1$s - %2$s",
     "Hidden" : "非公開",
     "can edit" : "編集を許可",
     "Calendar name …" : "カレンダー名 …",
