@@ -22,7 +22,6 @@ OC.L10N.register(
     "Appointments" : "Avtaler",
     "Schedule appointment \"%s\"" : "Registrer avtale \"%s\"",
     "Schedule an appointment" : "Registrer en avtale",
-    "%1$s - %2$s" : "%1$s - %2$s",
     "Prepare for %s" : "Forbered for %s",
     "Follow up for %s" : "Følg opp for %s",
     "Your appointment \"%s\" with %s needs confirmation" : "Avtalen din \"%s\" med %s trenger bekreftelse",
@@ -63,6 +62,7 @@ OC.L10N.register(
     "Appointment link could not be copied to clipboard" : "Avtalelenken ble ikke kopiert til utklippstavlen",
     "Preview" : "Forhåndsvis",
     "Copy link" : "Kopier lenke",
+    "Duplicate" : "Duplikat",
     "Edit" : "Rediger",
     "Delete" : "Slett",
     "Create new" : "Opprett ny",
@@ -204,6 +204,7 @@ OC.L10N.register(
     "Public – shown on the profile page" : "Offentlig – vises på profilsiden",
     "Private – only accessible via secret link" : "Privat – kun tilgjengelig via hemmelig lenke",
     "Update" : "Oppdater",
+    "(copy)" : "(kopier)",
     "Appointment name" : "Navn på avtale",
     "Location" : "Sted",
     "Create a Talk room" : "Opprett et Talk-rom",
@@ -313,6 +314,7 @@ OC.L10N.register(
     "Accept" : "Aksepter",
     "Decline" : "Avslå",
     "Tentative" : "Foreløpig",
+    "Copied to clipboard" : "Kopiert til utklippstavlen",
     "No attendees yet" : "Ingen deltakere enda",
     "Attendees" : "Deltakere",
     "Remove group" : "Fjern gruppe",
@@ -426,9 +428,9 @@ OC.L10N.register(
     "Personal" : "Personlig",
     "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "Den automatiske tidssonegjenkjenningen bestemte at tidssonen din var UTC.\nDette er mest sannsynlig et resultat av sikkerhetstiltak i nettleseren din.\nVennligst still inn tidssonen manuelt i kalenderinnstillingene.",
     "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Din konfigurerte tidssone ({timezoneId}) ble ikke funnet. Faller tilbake til UTC.\nVennligst endre tidssonen din i innstillingene og rapporter dette problemet.",
+    "Discard changes" : "Forkast endringer",
     "Edit event" : "Rediger hendelse",
     "Event does not exist" : "Hendelsen finnes ikke",
-    "Duplicate" : "Duplikat",
     "Delete this occurrence" : "Slett denne hendelsen",
     "Delete this and all future" : "Slett denne og fremtidige hendelser",
     "All day" : "Hele dagen",
@@ -439,6 +441,7 @@ OC.L10N.register(
     "_Attachment requires shared access_::_Attachments requiring shared access_" : ["Vedlegg som krever delt tilgang","Vedlegg som krever delt tilgang"],
     "Untitled event" : "Hendelse uten tittel",
     "Close" : "Lukk",
+    "This event was cancelled" : "Denne hendelsen ble kansellert",
     "Title" : "Navn",
     "30 min" : "30 min",
     "Participants" : "Deltakere",
@@ -535,6 +538,7 @@ OC.L10N.register(
     "Error while parsing a PROPFIND error" : "Feil under analyse av en PROPFIND-feil",
     "Appointment not found" : "Avtale ikke funnet",
     "User not found" : "Fant ikke brukeren",
+    "%1$s - %2$s" : "%1$s - %2$s",
     "Hidden" : "Skjult",
     "can edit" : "kan endre",
     "Calendar name …" : "Kalendernavn…",
@@ -560,7 +564,6 @@ OC.L10N.register(
     "Successfully appended link to talk room to description." : "La til lenke til Talk-rom til beskrivelsen.",
     "Error creating Talk room" : "Feil ved opprettelse av Talk-rom",
     "_%n more guest_::_%n more guests_" : ["%n gjest til","%n flere gjester"],
-    "The visibility of this event in shared calendars." : "Synlighet for denne oppføringen i delte kalendere",
-    "Keyboard shortcuts" : "Tastatursnarveier"
+    "The visibility of this event in shared calendars." : "Synlighet for denne oppføringen i delte kalendere"
 },
 "nplurals=2; plural=(n != 1);");
