@@ -65,6 +65,7 @@ OC.L10N.register(
     "Actions" : "Accions",
     "or" : "o",
     "General" : "Generals",
+    "Appearance" : "Aparéncia",
     "Editing" : "Edicion",
     "0 minutes" : "0 minuta",
     "Update" : "Metre a jorn",
@@ -109,6 +110,7 @@ OC.L10N.register(
     "Accept" : "Acceptar",
     "Decline" : "Declinar",
     "Tentative" : "Provisòri",
+    "Copied to clipboard" : "Copiat dins lo cartabèu",
     "Attendees" : "Convidats",
     "Remove group" : "Suprimir lo grop",
     "Remove color" : "Suprimir la color",
