@@ -94,6 +94,7 @@ OC.L10N.register(
     "Delete permanently" : "Eliminar permanentemente",
     "Could not update calendar order." : "Não foi possível atualizar a ordenação do calendário.",
     "Deck" : "Quadro",
+    "Internal link" : "Ligação interna",
     "Copy internal link" : "Copiar ligação interna",
     "An error occurred, unable to publish calendar." : "Ocorreu um erro, não foi possível publicar o calendário.",
     "An error occurred, unable to send email." : "Ocorreu um erro, não foi possível enviar o email.",
@@ -149,13 +150,11 @@ OC.L10N.register(
     "or" : "ou",
     "Calendar settings" : "Configurações do calendário",
     "No reminder" : "Nenhum lembrete",
-    "CalDAV link copied to clipboard." : "Ligação CalDAV copiada para a área de transferência.",
-    "CalDAV link could not be copied to clipboard." : "Não foi possível copiar a ligação CalDAV para a área de transferência.",
     "General" : "Geral",
-    "Copy iOS/macOS CalDAV address" : "Copiar endereço iOS/macOS CalDAV",
+    "Appearance" : "Aspeto",
     "Editing" : "A editar",
     "Default reminder" : "Lembrete padrão",
-    "Keyboard shortcuts" : "Atalhos de teclado",
+    "Files" : "Ficheiros",
     "_{duration} minute_::_{duration} minutes_" : ["{duration} minuto","{duration} minutos","{duration} minutos"],
     "0 minutes" : "0 minutos",
     "_{duration} hour_::_{duration} hours_" : ["{duration} hora","{duration} horas","{duration} horas"],
@@ -239,6 +238,7 @@ OC.L10N.register(
     "Accept" : "Aceitar",
     "Decline" : "Recusar",
     "Tentative" : "Tentativa",
+    "Copied to clipboard" : "Copiado para a área de transferência",
     "Attendees" : "Participantes",
     "From" : "De",
     "To" : "Para",
@@ -259,6 +259,7 @@ OC.L10N.register(
     "available" : "disponível",
     "Yes" : "Sim",
     "No" : "Não",
+    "Maybe" : "Talvez",
     "None" : "Nenhum",
     "Create" : "Criar",
     "Pick a date" : "Escolha uma data",
@@ -303,6 +304,8 @@ OC.L10N.register(
     "Calendar name …" : "Nome do calendário…",
     "Automatic ({detected})" : "Automático ({detected})",
     "Shortcut overview" : "Visão geral de atalhos",
+    "CalDAV link copied to clipboard." : "Ligação CalDAV copiada para a área de transferência.",
+    "CalDAV link could not be copied to clipboard." : "Não foi possível copiar a ligação CalDAV para a área de transferência.",
     "Enable birthday calendar" : "Ativar calendário de aniversários",
     "Show tasks in calendar" : "Mostrar tarefas no calendário",
     "Enable simplified editor" : "Ativar editor simplificado",
@@ -310,6 +313,7 @@ OC.L10N.register(
     "Show week numbers" : "Mostrar o número das semanas",
     "Time increments" : "Incrementos de tempo",
     "Copy primary CalDAV address" : "Copiar endereço CalDAV primário",
+    "Copy iOS/macOS CalDAV address" : "Copiar endereço iOS/macOS CalDAV",
     "Personal availability settings" : "Configurações de disponibilidade pessoal",
     "Show keyboard shortcuts" : "Mostrar atalhos de teclado"
 },
